@@ -19,18 +19,11 @@ class ApiClient(object):
         "Invalid oauth2 access token",
     )
 
-    _instance = None
-
     def __init__(self, config):
         self.config = config
         self.token = None
         self.proxy = config.get_proxy()
 
-    def __new__(cls, config, *args, **kwargs):
-        if not cls._instance:
-            cls._instance = object.__new__(cls, *args, **kwargs)
-
-        return cls._instance
 
     def _refresh_token(self):
         """
@@ -164,8 +157,11 @@ class ApiClient(object):
         trace_id = response.headers.get("Trace-Id")
         return trace_id if trace_id is not None else None
 
-    def fetch(self, query):
-        payload = query.params.serialize() if query.params else None
+    def fetch(self, query, use_empty_payload=False):
+        payload = query.params.serialize() if query.params is not None else None
+        if not payload and not use_empty_payload:
+            payload = None
+
         return self._request(
             query.method.name, query.endpoint, payload, params=query.query_string
         )
