@@ -1,6 +1,8 @@
 from trustar2.query import Query
-from trustar2.base import fluent, Methods
+from trustar2.base import fluent, Methods, STATUS_OK
+from trustar2.models.enclave import Enclave
 from trustar2.handlers.base_handler import BaseHandler
+from trustar2.models.trustar_response import TruStarResponse
 
 
 @fluent
@@ -24,9 +26,18 @@ class Account(BaseHandler):
 
     def ping(self):
         """Tests connectiviy against TruSTAR API."""
-        return self.create_query(Methods.GET, specific_endpoint="/ping").execute()
+        result = self.create_query(Methods.GET, specific_endpoint="/ping").execute()
+        return TruStarResponse(status_code=result.status_code, data={"result": result.text})
 
 
     def get_enclaves(self):
         """Returns all user enclaves with according permissions."""
-        return self.create_query(Methods.GET, specific_endpoint="/enclaves").execute()
+        result = self.create_query(Methods.GET, specific_endpoint="/enclaves").execute()
+        data = result.json()
+        if result.status_code == STATUS_OK:
+            data = [Enclave.from_dict(e) for e in data]
+        
+        return TruStarResponse(
+            status_code=result.status_code, 
+            data=data
+        )
